MiniInputContextPlatformInterface class abstract

Abstract input context for configuring and capturing input events.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(MiniAVInputConfig config) Future<void>
Configure the input context with the given config.
destroy() Future<void>
Destroy this input context and release resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCapture({void onKeyboard(MiniAVKeyboardEvent event, Object? userData)?, void onMouse(MiniAVMouseEvent event, Object? userData)?, void onGamepad(MiniAVGamepadEvent event, Object? userData)?, Object? userData}) Future<void>
Start input capture. Provide callbacks for each input type you want to receive.
stopCapture() Future<void>
Stop input capture.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited