MiniCameraContextPlatformInterface class abstract
Abstract camera context for configuring and capturing from a camera.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addLostListener(
MiniAVContextLostListener listener) → void Function() - Subscribe to a one-shot lost notification for this context (the device being captured was unplugged or otherwise became unavailable). The returned disposer must be called to unsubscribe (or the listener cleans itself up on context destroy).
-
configure(
String deviceId, MiniAVVideoInfo format) → Future< void> - Configure the camera context with a device and format.
-
destroy(
) → Future< void> - Destroy this camera context and release resources.
-
getConfiguredFormat(
) → Future< MiniAVVideoInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startCapture(
void onFrame(MiniAVBuffer buffer, Object? userData), {Object? userData}) → Future< void> -
Start camera capture.
onFrameis called for each frame received. -
stopCapture(
) → Future< void> - Stop camera capture.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited