configure abstract method
Prepare the injector for the given input types (bitmask of MiniAVInputType values — keyboard/mouse). On Linux this creates the backing uinput virtual device.
Implementation
Future<void> configure(int inputTypes);
Prepare the injector for the given input types (bitmask of MiniAVInputType values — keyboard/mouse). On Linux this creates the backing uinput virtual device.
Future<void> configure(int inputTypes);